# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/apploadbalancer/v1/backend_group.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from yandex.cloud.apploadbalancer.v1 import payload_pb2 as yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_payload__pb2
from yandex.cloud.apploadbalancer.v1 import tls_pb2 as yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_tls__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/apploadbalancer/v1/backend_group.proto',
  package='yandex.cloud.apploadbalancer.v1',
  syntax='proto3',
  serialized_options=b'\n#yandex.cloud.api.apploadbalancer.v1ZSgithub.com/yandex-cloud/go-genproto/yandex/cloud/apploadbalancer/v1;apploadbalancer',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n3yandex/cloud/apploadbalancer/v1/backend_group.proto\x12\x1fyandex.cloud.apploadbalancer.v1\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a-yandex/cloud/apploadbalancer/v1/payload.proto\x1a)yandex/cloud/apploadbalancer/v1/tls.proto\x1a\x1dyandex/cloud/validation.proto\"\xd2\x03\n\x0c\x42\x61\x63kendGroup\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x11\n\tfolder_id\x18\x04 \x01(\t\x12I\n\x06labels\x18\x05 \x03(\x0b\x32\x39.yandex.cloud.apploadbalancer.v1.BackendGroup.LabelsEntry\x12\x41\n\x04http\x18\x06 \x01(\x0b\x32\x31.yandex.cloud.apploadbalancer.v1.HttpBackendGroupH\x00\x12\x41\n\x04grpc\x18\x07 \x01(\x0b\x32\x31.yandex.cloud.apploadbalancer.v1.GrpcBackendGroupH\x00\x12\x45\n\x06stream\x18\n \x01(\x0b\x32\x33.yandex.cloud.apploadbalancer.v1.StreamBackendGroupH\x00\x12.\n\ncreated_at\x18\t \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\t\n\x07\x62\x61\x63kend\"\xbc\x01\n\x12StreamBackendGroup\x12@\n\x08\x62\x61\x63kends\x18\x01 \x03(\x0b\x32..yandex.cloud.apploadbalancer.v1.StreamBackend\x12P\n\nconnection\x18\x02 \x01(\x0b\x32:.yandex.cloud.apploadbalancer.v1.ConnectionSessionAffinityH\x00\x42\x12\n\x10session_affinity\"\xcc\x02\n\x10HttpBackendGroup\x12>\n\x08\x62\x61\x63kends\x18\x01 \x03(\x0b\x32,.yandex.cloud.apploadbalancer.v1.HttpBackend\x12P\n\nconnection\x18\x02 \x01(\x0b\x32:.yandex.cloud.apploadbalancer.v1.ConnectionSessionAffinityH\x00\x12H\n\x06header\x18\x03 \x01(\x0b\x32\x36.yandex.cloud.apploadbalancer.v1.HeaderSessionAffinityH\x00\x12H\n\x06\x63ookie\x18\x04 \x01(\x0b\x32\x36.yandex.cloud.apploadbalancer.v1.CookieSessionAffinityH\x00\x42\x12\n\x10session_affinity\"\xcc\x02\n\x10GrpcBackendGroup\x12>\n\x08\x62\x61\x63kends\x18\x01 \x03(\x0b\x32,.yandex.cloud.apploadbalancer.v1.GrpcBackend\x12P\n\nconnection\x18\x02 \x01(\x0b\x32:.yandex.cloud.apploadbalancer.v1.ConnectionSessionAffinityH\x00\x12H\n\x06header\x18\x03 \x01(\x0b\x32\x36.yandex.cloud.apploadbalancer.v1.HeaderSessionAffinityH\x00\x12H\n\x06\x63ookie\x18\x04 \x01(\x0b\x32\x36.yandex.cloud.apploadbalancer.v1.CookieSessionAffinityH\x00\x42\x12\n\x10session_affinity\"7\n\x15HeaderSessionAffinity\x12\x1e\n\x0bheader_name\x18\x01 \x01(\tB\t\x8a\xc8\x31\x05\x31-256\"X\n\x15\x43ookieSessionAffinity\x12\x17\n\x04name\x18\x01 \x01(\tB\t\x8a\xc8\x31\x05\x31-256\x12&\n\x03ttl\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\".\n\x19\x43onnectionSessionAffinity\x12\x11\n\tsource_ip\x18\x01 \x01(\x08\"\xc7\x01\n\x13LoadBalancingConfig\x12\"\n\x0fpanic_threshold\x18\x01 \x01(\x03\x42\t\xfa\xc7\x31\x05\x30-100\x12\x31\n\x1elocality_aware_routing_percent\x18\x02 \x01(\x03\x42\t\xfa\xc7\x31\x05\x30-100\x12\x17\n\x0fstrict_locality\x18\x03 \x01(\x08\x12@\n\x04mode\x18\x04 \x01(\x0e\x32\x32.yandex.cloud.apploadbalancer.v1.LoadBalancingMode\"\xe6\x03\n\rStreamBackend\x12.\n\x04name\x18\x01 \x01(\tB \xf2\xc7\x31\x1c[a-z][-a-z0-9]{1,61}[a-z0-9]\x12\x33\n\x0e\x62\x61\x63kend_weight\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12S\n\x15load_balancing_config\x18\x03 \x01(\x0b\x32\x34.yandex.cloud.apploadbalancer.v1.LoadBalancingConfig\x12\x19\n\x04port\x18\x04 \x01(\x03\x42\x0b\xfa\xc7\x31\x07\x30-65535\x12M\n\rtarget_groups\x18\x05 \x01(\x0b\x32\x34.yandex.cloud.apploadbalancer.v1.TargetGroupsBackendH\x00\x12\x42\n\x0chealthchecks\x18\x06 \x03(\x0b\x32,.yandex.cloud.apploadbalancer.v1.HealthCheck\x12\x38\n\x03tls\x18\x07 \x01(\x0b\x32+.yandex.cloud.apploadbalancer.v1.BackendTls\x12\x1d\n\x15\x65nable_proxy_protocol\x18\x08 \x01(\x08\x42\x14\n\x0c\x62\x61\x63kend_type\x12\x04\xc0\xc1\x31\x01\"\xad\x04\n\x0bHttpBackend\x12\x32\n\x04name\x18\x01 \x01(\tB$\xe8\xc7\x31\x01\xf2\xc7\x31\x1c[a-z][-a-z0-9]{1,61}[a-z0-9]\x12\x33\n\x0e\x62\x61\x63kend_weight\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12S\n\x15load_balancing_config\x18\x03 \x01(\x0b\x32\x34.yandex.cloud.apploadbalancer.v1.LoadBalancingConfig\x12\x19\n\x04port\x18\x04 \x01(\x03\x42\x0b\xfa\xc7\x31\x07\x30-65535\x12M\n\rtarget_groups\x18\x05 \x01(\x0b\x32\x34.yandex.cloud.apploadbalancer.v1.TargetGroupsBackendH\x00\x12O\n\x0estorage_bucket\x18\t \x01(\x0b\x32\x35.yandex.cloud.apploadbalancer.v1.StorageBucketBackendH\x00\x12\x42\n\x0chealthchecks\x18\x06 \x03(\x0b\x32,.yandex.cloud.apploadbalancer.v1.HealthCheck\x12\x38\n\x03tls\x18\x07 \x01(\x0b\x32+.yandex.cloud.apploadbalancer.v1.BackendTls\x12\x11\n\tuse_http2\x18\x08 \x01(\x08\x42\x14\n\x0c\x62\x61\x63kend_type\x12\x04\xc0\xc1\x31\x01\"\xc9\x03\n\x0bGrpcBackend\x12\x32\n\x04name\x18\x01 \x01(\tB$\xe8\xc7\x31\x01\xf2\xc7\x31\x1c[a-z][-a-z0-9]{1,61}[a-z0-9]\x12\x33\n\x0e\x62\x61\x63kend_weight\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12S\n\x15load_balancing_config\x18\x03 \x01(\x0b\x32\x34.yandex.cloud.apploadbalancer.v1.LoadBalancingConfig\x12\x19\n\x04port\x18\x04 \x01(\x03\x42\x0b\xfa\xc7\x31\x07\x30-65535\x12M\n\rtarget_groups\x18\x05 \x01(\x0b\x32\x34.yandex.cloud.apploadbalancer.v1.TargetGroupsBackendH\x00\x12\x42\n\x0chealthchecks\x18\x07 \x03(\x0b\x32,.yandex.cloud.apploadbalancer.v1.HealthCheck\x12\x38\n\x03tls\x18\x08 \x01(\x0b\x32+.yandex.cloud.apploadbalancer.v1.BackendTlsB\x14\n\x0c\x62\x61\x63kend_type\x12\x04\xc0\xc1\x31\x01\"7\n\x13TargetGroupsBackend\x12 \n\x10target_group_ids\x18\x01 \x03(\tB\x06\x82\xc8\x31\x02>0\"\x1c\n\x1aPlaintextTransportSettings\"v\n\x17SecureTransportSettings\x12\x0b\n\x03sni\x18\x01 \x01(\t\x12N\n\x12validation_context\x18\x03 \x01(\x0b\x32\x32.yandex.cloud.apploadbalancer.v1.ValidationContext\"i\n\nBackendTls\x12\x0b\n\x03sni\x18\x01 \x01(\t\x12N\n\x12validation_context\x18\x03 \x01(\x0b\x32\x32.yandex.cloud.apploadbalancer.v1.ValidationContext\",\n\x14StorageBucketBackend\x12\x14\n\x06\x62ucket\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"\xa0\x07\n\x0bHealthCheck\x12\x30\n\x07timeout\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationB\x04\xe8\xc7\x31\x01\x12\x31\n\x08interval\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB\x04\xe8\xc7\x31\x01\x12\x1f\n\x17interval_jitter_percent\x18\x03 \x01(\x01\x12\x19\n\x11healthy_threshold\x18\x04 \x01(\x03\x12\x1b\n\x13unhealthy_threshold\x18\x05 \x01(\x03\x12%\n\x10healthcheck_port\x18\x06 \x01(\x03\x42\x0b\xfa\xc7\x31\x07\x30-65535\x12P\n\x06stream\x18\x07 \x01(\x0b\x32>.yandex.cloud.apploadbalancer.v1.HealthCheck.StreamHealthCheckH\x00\x12L\n\x04http\x18\x08 \x01(\x0b\x32<.yandex.cloud.apploadbalancer.v1.HealthCheck.HttpHealthCheckH\x00\x12L\n\x04grpc\x18\t \x01(\x0b\x32<.yandex.cloud.apploadbalancer.v1.HealthCheck.GrpcHealthCheckH\x00\x12P\n\tplaintext\x18\n \x01(\x0b\x32;.yandex.cloud.apploadbalancer.v1.PlaintextTransportSettingsH\x01\x12G\n\x03tls\x18\x0b \x01(\x0b\x32\x38.yandex.cloud.apploadbalancer.v1.SecureTransportSettingsH\x01\x1a\x86\x01\n\x11StreamHealthCheck\x12\x36\n\x04send\x18\x01 \x01(\x0b\x32(.yandex.cloud.apploadbalancer.v1.Payload\x12\x39\n\x07receive\x18\x02 \x01(\x0b\x32(.yandex.cloud.apploadbalancer.v1.Payload\x1a\x46\n\x0fHttpHealthCheck\x12\x0c\n\x04host\x18\x01 \x01(\t\x12\x12\n\x04path\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x11\n\tuse_http2\x18\x03 \x01(\x08\x1a\'\n\x0fGrpcHealthCheck\x12\x14\n\x0cservice_name\x18\x01 \x01(\tB\x13\n\x0bhealthcheck\x12\x04\xc0\xc1\x31\x01\x42\x14\n\x12transport_settings*T\n\x11LoadBalancingMode\x12\x0f\n\x0bROUND_ROBIN\x10\x00\x12\n\n\x06RANDOM\x10\x01\x12\x11\n\rLEAST_REQUEST\x10\x02\x12\x0f\n\x0bMAGLEV_HASH\x10\x03\x42z\n#yandex.cloud.api.apploadbalancer.v1ZSgithub.com/yandex-cloud/go-genproto/yandex/cloud/apploadbalancer/v1;apploadbalancerb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_payload__pb2.DESCRIPTOR,yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_tls__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,])

_LOADBALANCINGMODE = _descriptor.EnumDescriptor(
  name='LoadBalancingMode',
  full_name='yandex.cloud.apploadbalancer.v1.LoadBalancingMode',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ROUND_ROBIN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RANDOM', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LEAST_REQUEST', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MAGLEV_HASH', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4833,
  serialized_end=4917,
)
_sym_db.RegisterEnumDescriptor(_LOADBALANCINGMODE)

LoadBalancingMode = enum_type_wrapper.EnumTypeWrapper(_LOADBALANCINGMODE)
ROUND_ROBIN = 0
RANDOM = 1
LEAST_REQUEST = 2
MAGLEV_HASH = 3



_BACKENDGROUP_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.apploadbalancer.v1.BackendGroup.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.apploadbalancer.v1.BackendGroup.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.apploadbalancer.v1.BackendGroup.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=717,
  serialized_end=762,
)

_BACKENDGROUP = _descriptor.Descriptor(
  name='BackendGroup',
  full_name='yandex.cloud.apploadbalancer.v1.BackendGroup',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='yandex.cloud.apploadbalancer.v1.BackendGroup.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.apploadbalancer.v1.BackendGroup.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.apploadbalancer.v1.BackendGroup.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.apploadbalancer.v1.BackendGroup.folder_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.apploadbalancer.v1.BackendGroup.labels', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='http', full_name='yandex.cloud.apploadbalancer.v1.BackendGroup.http', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='grpc', full_name='yandex.cloud.apploadbalancer.v1.BackendGroup.grpc', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stream', full_name='yandex.cloud.apploadbalancer.v1.BackendGroup.stream', index=7,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='yandex.cloud.apploadbalancer.v1.BackendGroup.created_at', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_BACKENDGROUP_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='backend', full_name='yandex.cloud.apploadbalancer.v1.BackendGroup.backend',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=307,
  serialized_end=773,
)


_STREAMBACKENDGROUP = _descriptor.Descriptor(
  name='StreamBackendGroup',
  full_name='yandex.cloud.apploadbalancer.v1.StreamBackendGroup',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='backends', full_name='yandex.cloud.apploadbalancer.v1.StreamBackendGroup.backends', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connection', full_name='yandex.cloud.apploadbalancer.v1.StreamBackendGroup.connection', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='session_affinity', full_name='yandex.cloud.apploadbalancer.v1.StreamBackendGroup.session_affinity',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=776,
  serialized_end=964,
)


_HTTPBACKENDGROUP = _descriptor.Descriptor(
  name='HttpBackendGroup',
  full_name='yandex.cloud.apploadbalancer.v1.HttpBackendGroup',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='backends', full_name='yandex.cloud.apploadbalancer.v1.HttpBackendGroup.backends', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connection', full_name='yandex.cloud.apploadbalancer.v1.HttpBackendGroup.connection', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='header', full_name='yandex.cloud.apploadbalancer.v1.HttpBackendGroup.header', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cookie', full_name='yandex.cloud.apploadbalancer.v1.HttpBackendGroup.cookie', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='session_affinity', full_name='yandex.cloud.apploadbalancer.v1.HttpBackendGroup.session_affinity',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=967,
  serialized_end=1299,
)


_GRPCBACKENDGROUP = _descriptor.Descriptor(
  name='GrpcBackendGroup',
  full_name='yandex.cloud.apploadbalancer.v1.GrpcBackendGroup',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='backends', full_name='yandex.cloud.apploadbalancer.v1.GrpcBackendGroup.backends', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connection', full_name='yandex.cloud.apploadbalancer.v1.GrpcBackendGroup.connection', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='header', full_name='yandex.cloud.apploadbalancer.v1.GrpcBackendGroup.header', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cookie', full_name='yandex.cloud.apploadbalancer.v1.GrpcBackendGroup.cookie', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='session_affinity', full_name='yandex.cloud.apploadbalancer.v1.GrpcBackendGroup.session_affinity',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1302,
  serialized_end=1634,
)


_HEADERSESSIONAFFINITY = _descriptor.Descriptor(
  name='HeaderSessionAffinity',
  full_name='yandex.cloud.apploadbalancer.v1.HeaderSessionAffinity',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header_name', full_name='yandex.cloud.apploadbalancer.v1.HeaderSessionAffinity.header_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\0051-256', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1636,
  serialized_end=1691,
)


_COOKIESESSIONAFFINITY = _descriptor.Descriptor(
  name='CookieSessionAffinity',
  full_name='yandex.cloud.apploadbalancer.v1.CookieSessionAffinity',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.apploadbalancer.v1.CookieSessionAffinity.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\0051-256', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ttl', full_name='yandex.cloud.apploadbalancer.v1.CookieSessionAffinity.ttl', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1693,
  serialized_end=1781,
)


_CONNECTIONSESSIONAFFINITY = _descriptor.Descriptor(
  name='ConnectionSessionAffinity',
  full_name='yandex.cloud.apploadbalancer.v1.ConnectionSessionAffinity',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='source_ip', full_name='yandex.cloud.apploadbalancer.v1.ConnectionSessionAffinity.source_ip', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1783,
  serialized_end=1829,
)


_LOADBALANCINGCONFIG = _descriptor.Descriptor(
  name='LoadBalancingConfig',
  full_name='yandex.cloud.apploadbalancer.v1.LoadBalancingConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='panic_threshold', full_name='yandex.cloud.apploadbalancer.v1.LoadBalancingConfig.panic_threshold', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0050-100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='locality_aware_routing_percent', full_name='yandex.cloud.apploadbalancer.v1.LoadBalancingConfig.locality_aware_routing_percent', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0050-100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='strict_locality', full_name='yandex.cloud.apploadbalancer.v1.LoadBalancingConfig.strict_locality', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mode', full_name='yandex.cloud.apploadbalancer.v1.LoadBalancingConfig.mode', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1832,
  serialized_end=2031,
)


_STREAMBACKEND = _descriptor.Descriptor(
  name='StreamBackend',
  full_name='yandex.cloud.apploadbalancer.v1.StreamBackend',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.apploadbalancer.v1.StreamBackend.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\3071\034[a-z][-a-z0-9]{1,61}[a-z0-9]', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='backend_weight', full_name='yandex.cloud.apploadbalancer.v1.StreamBackend.backend_weight', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='load_balancing_config', full_name='yandex.cloud.apploadbalancer.v1.StreamBackend.load_balancing_config', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='port', full_name='yandex.cloud.apploadbalancer.v1.StreamBackend.port', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0070-65535', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='target_groups', full_name='yandex.cloud.apploadbalancer.v1.StreamBackend.target_groups', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='healthchecks', full_name='yandex.cloud.apploadbalancer.v1.StreamBackend.healthchecks', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tls', full_name='yandex.cloud.apploadbalancer.v1.StreamBackend.tls', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_proxy_protocol', full_name='yandex.cloud.apploadbalancer.v1.StreamBackend.enable_proxy_protocol', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='backend_type', full_name='yandex.cloud.apploadbalancer.v1.StreamBackend.backend_type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\300\3011\001'),
  ],
  serialized_start=2034,
  serialized_end=2520,
)


_HTTPBACKEND = _descriptor.Descriptor(
  name='HttpBackend',
  full_name='yandex.cloud.apploadbalancer.v1.HttpBackend',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.apploadbalancer.v1.HttpBackend.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\362\3071\034[a-z][-a-z0-9]{1,61}[a-z0-9]', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='backend_weight', full_name='yandex.cloud.apploadbalancer.v1.HttpBackend.backend_weight', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='load_balancing_config', full_name='yandex.cloud.apploadbalancer.v1.HttpBackend.load_balancing_config', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='port', full_name='yandex.cloud.apploadbalancer.v1.HttpBackend.port', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0070-65535', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='target_groups', full_name='yandex.cloud.apploadbalancer.v1.HttpBackend.target_groups', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='storage_bucket', full_name='yandex.cloud.apploadbalancer.v1.HttpBackend.storage_bucket', index=5,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='healthchecks', full_name='yandex.cloud.apploadbalancer.v1.HttpBackend.healthchecks', index=6,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tls', full_name='yandex.cloud.apploadbalancer.v1.HttpBackend.tls', index=7,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='use_http2', full_name='yandex.cloud.apploadbalancer.v1.HttpBackend.use_http2', index=8,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='backend_type', full_name='yandex.cloud.apploadbalancer.v1.HttpBackend.backend_type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\300\3011\001'),
  ],
  serialized_start=2523,
  serialized_end=3080,
)


_GRPCBACKEND = _descriptor.Descriptor(
  name='GrpcBackend',
  full_name='yandex.cloud.apploadbalancer.v1.GrpcBackend',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.apploadbalancer.v1.GrpcBackend.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\362\3071\034[a-z][-a-z0-9]{1,61}[a-z0-9]', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='backend_weight', full_name='yandex.cloud.apploadbalancer.v1.GrpcBackend.backend_weight', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='load_balancing_config', full_name='yandex.cloud.apploadbalancer.v1.GrpcBackend.load_balancing_config', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='port', full_name='yandex.cloud.apploadbalancer.v1.GrpcBackend.port', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0070-65535', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='target_groups', full_name='yandex.cloud.apploadbalancer.v1.GrpcBackend.target_groups', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='healthchecks', full_name='yandex.cloud.apploadbalancer.v1.GrpcBackend.healthchecks', index=5,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tls', full_name='yandex.cloud.apploadbalancer.v1.GrpcBackend.tls', index=6,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='backend_type', full_name='yandex.cloud.apploadbalancer.v1.GrpcBackend.backend_type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\300\3011\001'),
  ],
  serialized_start=3083,
  serialized_end=3540,
)


_TARGETGROUPSBACKEND = _descriptor.Descriptor(
  name='TargetGroupsBackend',
  full_name='yandex.cloud.apploadbalancer.v1.TargetGroupsBackend',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='target_group_ids', full_name='yandex.cloud.apploadbalancer.v1.TargetGroupsBackend.target_group_ids', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\002>0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3542,
  serialized_end=3597,
)


_PLAINTEXTTRANSPORTSETTINGS = _descriptor.Descriptor(
  name='PlaintextTransportSettings',
  full_name='yandex.cloud.apploadbalancer.v1.PlaintextTransportSettings',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3599,
  serialized_end=3627,
)


_SECURETRANSPORTSETTINGS = _descriptor.Descriptor(
  name='SecureTransportSettings',
  full_name='yandex.cloud.apploadbalancer.v1.SecureTransportSettings',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sni', full_name='yandex.cloud.apploadbalancer.v1.SecureTransportSettings.sni', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='validation_context', full_name='yandex.cloud.apploadbalancer.v1.SecureTransportSettings.validation_context', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3629,
  serialized_end=3747,
)


_BACKENDTLS = _descriptor.Descriptor(
  name='BackendTls',
  full_name='yandex.cloud.apploadbalancer.v1.BackendTls',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sni', full_name='yandex.cloud.apploadbalancer.v1.BackendTls.sni', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='validation_context', full_name='yandex.cloud.apploadbalancer.v1.BackendTls.validation_context', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3749,
  serialized_end=3854,
)


_STORAGEBUCKETBACKEND = _descriptor.Descriptor(
  name='StorageBucketBackend',
  full_name='yandex.cloud.apploadbalancer.v1.StorageBucketBackend',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='bucket', full_name='yandex.cloud.apploadbalancer.v1.StorageBucketBackend.bucket', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3856,
  serialized_end=3900,
)


_HEALTHCHECK_STREAMHEALTHCHECK = _descriptor.Descriptor(
  name='StreamHealthCheck',
  full_name='yandex.cloud.apploadbalancer.v1.HealthCheck.StreamHealthCheck',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='send', full_name='yandex.cloud.apploadbalancer.v1.HealthCheck.StreamHealthCheck.send', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='receive', full_name='yandex.cloud.apploadbalancer.v1.HealthCheck.StreamHealthCheck.receive', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4541,
  serialized_end=4675,
)

_HEALTHCHECK_HTTPHEALTHCHECK = _descriptor.Descriptor(
  name='HttpHealthCheck',
  full_name='yandex.cloud.apploadbalancer.v1.HealthCheck.HttpHealthCheck',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='host', full_name='yandex.cloud.apploadbalancer.v1.HealthCheck.HttpHealthCheck.host', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path', full_name='yandex.cloud.apploadbalancer.v1.HealthCheck.HttpHealthCheck.path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='use_http2', full_name='yandex.cloud.apploadbalancer.v1.HealthCheck.HttpHealthCheck.use_http2', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4677,
  serialized_end=4747,
)

_HEALTHCHECK_GRPCHEALTHCHECK = _descriptor.Descriptor(
  name='GrpcHealthCheck',
  full_name='yandex.cloud.apploadbalancer.v1.HealthCheck.GrpcHealthCheck',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='service_name', full_name='yandex.cloud.apploadbalancer.v1.HealthCheck.GrpcHealthCheck.service_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4749,
  serialized_end=4788,
)

_HEALTHCHECK = _descriptor.Descriptor(
  name='HealthCheck',
  full_name='yandex.cloud.apploadbalancer.v1.HealthCheck',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='timeout', full_name='yandex.cloud.apploadbalancer.v1.HealthCheck.timeout', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='interval', full_name='yandex.cloud.apploadbalancer.v1.HealthCheck.interval', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='interval_jitter_percent', full_name='yandex.cloud.apploadbalancer.v1.HealthCheck.interval_jitter_percent', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='healthy_threshold', full_name='yandex.cloud.apploadbalancer.v1.HealthCheck.healthy_threshold', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unhealthy_threshold', full_name='yandex.cloud.apploadbalancer.v1.HealthCheck.unhealthy_threshold', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='healthcheck_port', full_name='yandex.cloud.apploadbalancer.v1.HealthCheck.healthcheck_port', index=5,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0070-65535', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stream', full_name='yandex.cloud.apploadbalancer.v1.HealthCheck.stream', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='http', full_name='yandex.cloud.apploadbalancer.v1.HealthCheck.http', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='grpc', full_name='yandex.cloud.apploadbalancer.v1.HealthCheck.grpc', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='plaintext', full_name='yandex.cloud.apploadbalancer.v1.HealthCheck.plaintext', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tls', full_name='yandex.cloud.apploadbalancer.v1.HealthCheck.tls', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_HEALTHCHECK_STREAMHEALTHCHECK, _HEALTHCHECK_HTTPHEALTHCHECK, _HEALTHCHECK_GRPCHEALTHCHECK, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='healthcheck', full_name='yandex.cloud.apploadbalancer.v1.HealthCheck.healthcheck',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\300\3011\001'),
    _descriptor.OneofDescriptor(
      name='transport_settings', full_name='yandex.cloud.apploadbalancer.v1.HealthCheck.transport_settings',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=3903,
  serialized_end=4831,
)

_BACKENDGROUP_LABELSENTRY.containing_type = _BACKENDGROUP
_BACKENDGROUP.fields_by_name['labels'].message_type = _BACKENDGROUP_LABELSENTRY
_BACKENDGROUP.fields_by_name['http'].message_type = _HTTPBACKENDGROUP
_BACKENDGROUP.fields_by_name['grpc'].message_type = _GRPCBACKENDGROUP
_BACKENDGROUP.fields_by_name['stream'].message_type = _STREAMBACKENDGROUP
_BACKENDGROUP.fields_by_name['created_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_BACKENDGROUP.oneofs_by_name['backend'].fields.append(
  _BACKENDGROUP.fields_by_name['http'])
_BACKENDGROUP.fields_by_name['http'].containing_oneof = _BACKENDGROUP.oneofs_by_name['backend']
_BACKENDGROUP.oneofs_by_name['backend'].fields.append(
  _BACKENDGROUP.fields_by_name['grpc'])
_BACKENDGROUP.fields_by_name['grpc'].containing_oneof = _BACKENDGROUP.oneofs_by_name['backend']
_BACKENDGROUP.oneofs_by_name['backend'].fields.append(
  _BACKENDGROUP.fields_by_name['stream'])
_BACKENDGROUP.fields_by_name['stream'].containing_oneof = _BACKENDGROUP.oneofs_by_name['backend']
_STREAMBACKENDGROUP.fields_by_name['backends'].message_type = _STREAMBACKEND
_STREAMBACKENDGROUP.fields_by_name['connection'].message_type = _CONNECTIONSESSIONAFFINITY
_STREAMBACKENDGROUP.oneofs_by_name['session_affinity'].fields.append(
  _STREAMBACKENDGROUP.fields_by_name['connection'])
_STREAMBACKENDGROUP.fields_by_name['connection'].containing_oneof = _STREAMBACKENDGROUP.oneofs_by_name['session_affinity']
_HTTPBACKENDGROUP.fields_by_name['backends'].message_type = _HTTPBACKEND
_HTTPBACKENDGROUP.fields_by_name['connection'].message_type = _CONNECTIONSESSIONAFFINITY
_HTTPBACKENDGROUP.fields_by_name['header'].message_type = _HEADERSESSIONAFFINITY
_HTTPBACKENDGROUP.fields_by_name['cookie'].message_type = _COOKIESESSIONAFFINITY
_HTTPBACKENDGROUP.oneofs_by_name['session_affinity'].fields.append(
  _HTTPBACKENDGROUP.fields_by_name['connection'])
_HTTPBACKENDGROUP.fields_by_name['connection'].containing_oneof = _HTTPBACKENDGROUP.oneofs_by_name['session_affinity']
_HTTPBACKENDGROUP.oneofs_by_name['session_affinity'].fields.append(
  _HTTPBACKENDGROUP.fields_by_name['header'])
_HTTPBACKENDGROUP.fields_by_name['header'].containing_oneof = _HTTPBACKENDGROUP.oneofs_by_name['session_affinity']
_HTTPBACKENDGROUP.oneofs_by_name['session_affinity'].fields.append(
  _HTTPBACKENDGROUP.fields_by_name['cookie'])
_HTTPBACKENDGROUP.fields_by_name['cookie'].containing_oneof = _HTTPBACKENDGROUP.oneofs_by_name['session_affinity']
_GRPCBACKENDGROUP.fields_by_name['backends'].message_type = _GRPCBACKEND
_GRPCBACKENDGROUP.fields_by_name['connection'].message_type = _CONNECTIONSESSIONAFFINITY
_GRPCBACKENDGROUP.fields_by_name['header'].message_type = _HEADERSESSIONAFFINITY
_GRPCBACKENDGROUP.fields_by_name['cookie'].message_type = _COOKIESESSIONAFFINITY
_GRPCBACKENDGROUP.oneofs_by_name['session_affinity'].fields.append(
  _GRPCBACKENDGROUP.fields_by_name['connection'])
_GRPCBACKENDGROUP.fields_by_name['connection'].containing_oneof = _GRPCBACKENDGROUP.oneofs_by_name['session_affinity']
_GRPCBACKENDGROUP.oneofs_by_name['session_affinity'].fields.append(
  _GRPCBACKENDGROUP.fields_by_name['header'])
_GRPCBACKENDGROUP.fields_by_name['header'].containing_oneof = _GRPCBACKENDGROUP.oneofs_by_name['session_affinity']
_GRPCBACKENDGROUP.oneofs_by_name['session_affinity'].fields.append(
  _GRPCBACKENDGROUP.fields_by_name['cookie'])
_GRPCBACKENDGROUP.fields_by_name['cookie'].containing_oneof = _GRPCBACKENDGROUP.oneofs_by_name['session_affinity']
_COOKIESESSIONAFFINITY.fields_by_name['ttl'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_LOADBALANCINGCONFIG.fields_by_name['mode'].enum_type = _LOADBALANCINGMODE
_STREAMBACKEND.fields_by_name['backend_weight'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_STREAMBACKEND.fields_by_name['load_balancing_config'].message_type = _LOADBALANCINGCONFIG
_STREAMBACKEND.fields_by_name['target_groups'].message_type = _TARGETGROUPSBACKEND
_STREAMBACKEND.fields_by_name['healthchecks'].message_type = _HEALTHCHECK
_STREAMBACKEND.fields_by_name['tls'].message_type = _BACKENDTLS
_STREAMBACKEND.oneofs_by_name['backend_type'].fields.append(
  _STREAMBACKEND.fields_by_name['target_groups'])
_STREAMBACKEND.fields_by_name['target_groups'].containing_oneof = _STREAMBACKEND.oneofs_by_name['backend_type']
_HTTPBACKEND.fields_by_name['backend_weight'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_HTTPBACKEND.fields_by_name['load_balancing_config'].message_type = _LOADBALANCINGCONFIG
_HTTPBACKEND.fields_by_name['target_groups'].message_type = _TARGETGROUPSBACKEND
_HTTPBACKEND.fields_by_name['storage_bucket'].message_type = _STORAGEBUCKETBACKEND
_HTTPBACKEND.fields_by_name['healthchecks'].message_type = _HEALTHCHECK
_HTTPBACKEND.fields_by_name['tls'].message_type = _BACKENDTLS
_HTTPBACKEND.oneofs_by_name['backend_type'].fields.append(
  _HTTPBACKEND.fields_by_name['target_groups'])
_HTTPBACKEND.fields_by_name['target_groups'].containing_oneof = _HTTPBACKEND.oneofs_by_name['backend_type']
_HTTPBACKEND.oneofs_by_name['backend_type'].fields.append(
  _HTTPBACKEND.fields_by_name['storage_bucket'])
_HTTPBACKEND.fields_by_name['storage_bucket'].containing_oneof = _HTTPBACKEND.oneofs_by_name['backend_type']
_GRPCBACKEND.fields_by_name['backend_weight'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_GRPCBACKEND.fields_by_name['load_balancing_config'].message_type = _LOADBALANCINGCONFIG
_GRPCBACKEND.fields_by_name['target_groups'].message_type = _TARGETGROUPSBACKEND
_GRPCBACKEND.fields_by_name['healthchecks'].message_type = _HEALTHCHECK
_GRPCBACKEND.fields_by_name['tls'].message_type = _BACKENDTLS
_GRPCBACKEND.oneofs_by_name['backend_type'].fields.append(
  _GRPCBACKEND.fields_by_name['target_groups'])
_GRPCBACKEND.fields_by_name['target_groups'].containing_oneof = _GRPCBACKEND.oneofs_by_name['backend_type']
_SECURETRANSPORTSETTINGS.fields_by_name['validation_context'].message_type = yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_tls__pb2._VALIDATIONCONTEXT
_BACKENDTLS.fields_by_name['validation_context'].message_type = yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_tls__pb2._VALIDATIONCONTEXT
_HEALTHCHECK_STREAMHEALTHCHECK.fields_by_name['send'].message_type = yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_payload__pb2._PAYLOAD
_HEALTHCHECK_STREAMHEALTHCHECK.fields_by_name['receive'].message_type = yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_payload__pb2._PAYLOAD
_HEALTHCHECK_STREAMHEALTHCHECK.containing_type = _HEALTHCHECK
_HEALTHCHECK_HTTPHEALTHCHECK.containing_type = _HEALTHCHECK
_HEALTHCHECK_GRPCHEALTHCHECK.containing_type = _HEALTHCHECK
_HEALTHCHECK.fields_by_name['timeout'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_HEALTHCHECK.fields_by_name['interval'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_HEALTHCHECK.fields_by_name['stream'].message_type = _HEALTHCHECK_STREAMHEALTHCHECK
_HEALTHCHECK.fields_by_name['http'].message_type = _HEALTHCHECK_HTTPHEALTHCHECK
_HEALTHCHECK.fields_by_name['grpc'].message_type = _HEALTHCHECK_GRPCHEALTHCHECK
_HEALTHCHECK.fields_by_name['plaintext'].message_type = _PLAINTEXTTRANSPORTSETTINGS
_HEALTHCHECK.fields_by_name['tls'].message_type = _SECURETRANSPORTSETTINGS
_HEALTHCHECK.oneofs_by_name['healthcheck'].fields.append(
  _HEALTHCHECK.fields_by_name['stream'])
_HEALTHCHECK.fields_by_name['stream'].containing_oneof = _HEALTHCHECK.oneofs_by_name['healthcheck']
_HEALTHCHECK.oneofs_by_name['healthcheck'].fields.append(
  _HEALTHCHECK.fields_by_name['http'])
_HEALTHCHECK.fields_by_name['http'].containing_oneof = _HEALTHCHECK.oneofs_by_name['healthcheck']
_HEALTHCHECK.oneofs_by_name['healthcheck'].fields.append(
  _HEALTHCHECK.fields_by_name['grpc'])
_HEALTHCHECK.fields_by_name['grpc'].containing_oneof = _HEALTHCHECK.oneofs_by_name['healthcheck']
_HEALTHCHECK.oneofs_by_name['transport_settings'].fields.append(
  _HEALTHCHECK.fields_by_name['plaintext'])
_HEALTHCHECK.fields_by_name['plaintext'].containing_oneof = _HEALTHCHECK.oneofs_by_name['transport_settings']
_HEALTHCHECK.oneofs_by_name['transport_settings'].fields.append(
  _HEALTHCHECK.fields_by_name['tls'])
_HEALTHCHECK.fields_by_name['tls'].containing_oneof = _HEALTHCHECK.oneofs_by_name['transport_settings']
DESCRIPTOR.message_types_by_name['BackendGroup'] = _BACKENDGROUP
DESCRIPTOR.message_types_by_name['StreamBackendGroup'] = _STREAMBACKENDGROUP
DESCRIPTOR.message_types_by_name['HttpBackendGroup'] = _HTTPBACKENDGROUP
DESCRIPTOR.message_types_by_name['GrpcBackendGroup'] = _GRPCBACKENDGROUP
DESCRIPTOR.message_types_by_name['HeaderSessionAffinity'] = _HEADERSESSIONAFFINITY
DESCRIPTOR.message_types_by_name['CookieSessionAffinity'] = _COOKIESESSIONAFFINITY
DESCRIPTOR.message_types_by_name['ConnectionSessionAffinity'] = _CONNECTIONSESSIONAFFINITY
DESCRIPTOR.message_types_by_name['LoadBalancingConfig'] = _LOADBALANCINGCONFIG
DESCRIPTOR.message_types_by_name['StreamBackend'] = _STREAMBACKEND
DESCRIPTOR.message_types_by_name['HttpBackend'] = _HTTPBACKEND
DESCRIPTOR.message_types_by_name['GrpcBackend'] = _GRPCBACKEND
DESCRIPTOR.message_types_by_name['TargetGroupsBackend'] = _TARGETGROUPSBACKEND
DESCRIPTOR.message_types_by_name['PlaintextTransportSettings'] = _PLAINTEXTTRANSPORTSETTINGS
DESCRIPTOR.message_types_by_name['SecureTransportSettings'] = _SECURETRANSPORTSETTINGS
DESCRIPTOR.message_types_by_name['BackendTls'] = _BACKENDTLS
DESCRIPTOR.message_types_by_name['StorageBucketBackend'] = _STORAGEBUCKETBACKEND
DESCRIPTOR.message_types_by_name['HealthCheck'] = _HEALTHCHECK
DESCRIPTOR.enum_types_by_name['LoadBalancingMode'] = _LOADBALANCINGMODE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

BackendGroup = _reflection.GeneratedProtocolMessageType('BackendGroup', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _BACKENDGROUP_LABELSENTRY,
    '__module__' : 'yandex.cloud.apploadbalancer.v1.backend_group_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.BackendGroup.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _BACKENDGROUP,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.backend_group_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.BackendGroup)
  })
_sym_db.RegisterMessage(BackendGroup)
_sym_db.RegisterMessage(BackendGroup.LabelsEntry)

StreamBackendGroup = _reflection.GeneratedProtocolMessageType('StreamBackendGroup', (_message.Message,), {
  'DESCRIPTOR' : _STREAMBACKENDGROUP,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.backend_group_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.StreamBackendGroup)
  })
_sym_db.RegisterMessage(StreamBackendGroup)

HttpBackendGroup = _reflection.GeneratedProtocolMessageType('HttpBackendGroup', (_message.Message,), {
  'DESCRIPTOR' : _HTTPBACKENDGROUP,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.backend_group_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.HttpBackendGroup)
  })
_sym_db.RegisterMessage(HttpBackendGroup)

GrpcBackendGroup = _reflection.GeneratedProtocolMessageType('GrpcBackendGroup', (_message.Message,), {
  'DESCRIPTOR' : _GRPCBACKENDGROUP,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.backend_group_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.GrpcBackendGroup)
  })
_sym_db.RegisterMessage(GrpcBackendGroup)

HeaderSessionAffinity = _reflection.GeneratedProtocolMessageType('HeaderSessionAffinity', (_message.Message,), {
  'DESCRIPTOR' : _HEADERSESSIONAFFINITY,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.backend_group_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.HeaderSessionAffinity)
  })
_sym_db.RegisterMessage(HeaderSessionAffinity)

CookieSessionAffinity = _reflection.GeneratedProtocolMessageType('CookieSessionAffinity', (_message.Message,), {
  'DESCRIPTOR' : _COOKIESESSIONAFFINITY,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.backend_group_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.CookieSessionAffinity)
  })
_sym_db.RegisterMessage(CookieSessionAffinity)

ConnectionSessionAffinity = _reflection.GeneratedProtocolMessageType('ConnectionSessionAffinity', (_message.Message,), {
  'DESCRIPTOR' : _CONNECTIONSESSIONAFFINITY,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.backend_group_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.ConnectionSessionAffinity)
  })
_sym_db.RegisterMessage(ConnectionSessionAffinity)

LoadBalancingConfig = _reflection.GeneratedProtocolMessageType('LoadBalancingConfig', (_message.Message,), {
  'DESCRIPTOR' : _LOADBALANCINGCONFIG,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.backend_group_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.LoadBalancingConfig)
  })
_sym_db.RegisterMessage(LoadBalancingConfig)

StreamBackend = _reflection.GeneratedProtocolMessageType('StreamBackend', (_message.Message,), {
  'DESCRIPTOR' : _STREAMBACKEND,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.backend_group_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.StreamBackend)
  })
_sym_db.RegisterMessage(StreamBackend)

HttpBackend = _reflection.GeneratedProtocolMessageType('HttpBackend', (_message.Message,), {
  'DESCRIPTOR' : _HTTPBACKEND,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.backend_group_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.HttpBackend)
  })
_sym_db.RegisterMessage(HttpBackend)

GrpcBackend = _reflection.GeneratedProtocolMessageType('GrpcBackend', (_message.Message,), {
  'DESCRIPTOR' : _GRPCBACKEND,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.backend_group_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.GrpcBackend)
  })
_sym_db.RegisterMessage(GrpcBackend)

TargetGroupsBackend = _reflection.GeneratedProtocolMessageType('TargetGroupsBackend', (_message.Message,), {
  'DESCRIPTOR' : _TARGETGROUPSBACKEND,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.backend_group_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.TargetGroupsBackend)
  })
_sym_db.RegisterMessage(TargetGroupsBackend)

PlaintextTransportSettings = _reflection.GeneratedProtocolMessageType('PlaintextTransportSettings', (_message.Message,), {
  'DESCRIPTOR' : _PLAINTEXTTRANSPORTSETTINGS,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.backend_group_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.PlaintextTransportSettings)
  })
_sym_db.RegisterMessage(PlaintextTransportSettings)

SecureTransportSettings = _reflection.GeneratedProtocolMessageType('SecureTransportSettings', (_message.Message,), {
  'DESCRIPTOR' : _SECURETRANSPORTSETTINGS,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.backend_group_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.SecureTransportSettings)
  })
_sym_db.RegisterMessage(SecureTransportSettings)

BackendTls = _reflection.GeneratedProtocolMessageType('BackendTls', (_message.Message,), {
  'DESCRIPTOR' : _BACKENDTLS,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.backend_group_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.BackendTls)
  })
_sym_db.RegisterMessage(BackendTls)

StorageBucketBackend = _reflection.GeneratedProtocolMessageType('StorageBucketBackend', (_message.Message,), {
  'DESCRIPTOR' : _STORAGEBUCKETBACKEND,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.backend_group_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.StorageBucketBackend)
  })
_sym_db.RegisterMessage(StorageBucketBackend)

HealthCheck = _reflection.GeneratedProtocolMessageType('HealthCheck', (_message.Message,), {

  'StreamHealthCheck' : _reflection.GeneratedProtocolMessageType('StreamHealthCheck', (_message.Message,), {
    'DESCRIPTOR' : _HEALTHCHECK_STREAMHEALTHCHECK,
    '__module__' : 'yandex.cloud.apploadbalancer.v1.backend_group_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.HealthCheck.StreamHealthCheck)
    })
  ,

  'HttpHealthCheck' : _reflection.GeneratedProtocolMessageType('HttpHealthCheck', (_message.Message,), {
    'DESCRIPTOR' : _HEALTHCHECK_HTTPHEALTHCHECK,
    '__module__' : 'yandex.cloud.apploadbalancer.v1.backend_group_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.HealthCheck.HttpHealthCheck)
    })
  ,

  'GrpcHealthCheck' : _reflection.GeneratedProtocolMessageType('GrpcHealthCheck', (_message.Message,), {
    'DESCRIPTOR' : _HEALTHCHECK_GRPCHEALTHCHECK,
    '__module__' : 'yandex.cloud.apploadbalancer.v1.backend_group_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.HealthCheck.GrpcHealthCheck)
    })
  ,
  'DESCRIPTOR' : _HEALTHCHECK,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.backend_group_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.HealthCheck)
  })
_sym_db.RegisterMessage(HealthCheck)
_sym_db.RegisterMessage(HealthCheck.StreamHealthCheck)
_sym_db.RegisterMessage(HealthCheck.HttpHealthCheck)
_sym_db.RegisterMessage(HealthCheck.GrpcHealthCheck)


DESCRIPTOR._options = None
_BACKENDGROUP_LABELSENTRY._options = None
_HEADERSESSIONAFFINITY.fields_by_name['header_name']._options = None
_COOKIESESSIONAFFINITY.fields_by_name['name']._options = None
_LOADBALANCINGCONFIG.fields_by_name['panic_threshold']._options = None
_LOADBALANCINGCONFIG.fields_by_name['locality_aware_routing_percent']._options = None
_STREAMBACKEND.oneofs_by_name['backend_type']._options = None
_STREAMBACKEND.fields_by_name['name']._options = None
_STREAMBACKEND.fields_by_name['port']._options = None
_HTTPBACKEND.oneofs_by_name['backend_type']._options = None
_HTTPBACKEND.fields_by_name['name']._options = None
_HTTPBACKEND.fields_by_name['port']._options = None
_GRPCBACKEND.oneofs_by_name['backend_type']._options = None
_GRPCBACKEND.fields_by_name['name']._options = None
_GRPCBACKEND.fields_by_name['port']._options = None
_TARGETGROUPSBACKEND.fields_by_name['target_group_ids']._options = None
_STORAGEBUCKETBACKEND.fields_by_name['bucket']._options = None
_HEALTHCHECK_HTTPHEALTHCHECK.fields_by_name['path']._options = None
_HEALTHCHECK.oneofs_by_name['healthcheck']._options = None
_HEALTHCHECK.fields_by_name['timeout']._options = None
_HEALTHCHECK.fields_by_name['interval']._options = None
_HEALTHCHECK.fields_by_name['healthcheck_port']._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from yandex.cloud.compute.v1 import disk_pb2 as yandex_dot_cloud_dot_compute_dot_v1_dot_disk__pb2
from yandex.cloud.compute.v1 import disk_service_pb2 as yandex_dot_cloud_dot_compute_dot_v1_dot_disk__service__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2


class DiskServiceStub(object):
    """A set of methods for managing Disk resources.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Get = channel.unary_unary(
                '/yandex.cloud.compute.v1.DiskService/Get',
                request_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_disk__service__pb2.GetDiskRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_disk__pb2.Disk.FromString,
                )
        self.List = channel.unary_unary(
                '/yandex.cloud.compute.v1.DiskService/List',
                request_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_disk__service__pb2.ListDisksRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_disk__service__pb2.ListDisksResponse.FromString,
                )
        self.Create = channel.unary_unary(
                '/yandex.cloud.compute.v1.DiskService/Create',
                request_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_disk__service__pb2.CreateDiskRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.Update = channel.unary_unary(
                '/yandex.cloud.compute.v1.DiskService/Update',
                request_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_disk__service__pb2.UpdateDiskRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.Delete = channel.unary_unary(
                '/yandex.cloud.compute.v1.DiskService/Delete',
                request_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_disk__service__pb2.DeleteDiskRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.ListOperations = channel.unary_unary(
                '/yandex.cloud.compute.v1.DiskService/ListOperations',
                request_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_disk__service__pb2.ListDiskOperationsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_disk__service__pb2.ListDiskOperationsResponse.FromString,
                )
        self.Move = channel.unary_unary(
                '/yandex.cloud.compute.v1.DiskService/Move',
                request_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_disk__service__pb2.MoveDiskRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.ListSnapshotSchedules = channel.unary_unary(
                '/yandex.cloud.compute.v1.DiskService/ListSnapshotSchedules',
                request_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_disk__service__pb2.ListDiskSnapshotSchedulesRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_disk__service__pb2.ListDiskSnapshotSchedulesResponse.FromString,
                )


class DiskServiceServicer(object):
    """A set of methods for managing Disk resources.
    """

    def Get(self, request, context):
        """Returns the specified Disk resource.

        To get the list of available Disk resources, make a [List] request.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def List(self, request, context):
        """Retrieves the list of Disk resources in the specified folder.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Create(self, request, context):
        """Creates a disk in the specified folder.

        You can create an empty disk or restore it from a snapshot or an image.
        Method starts an asynchronous operation that can be cancelled while it is in progress.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Update(self, request, context):
        """Updates the specified disk.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Delete(self, request, context):
        """Deletes the specified disk.

        Deleting a disk removes its data permanently and is irreversible. However, deleting a disk does not delete
        any snapshots or images previously made from the disk. You must delete snapshots and images separately.

        It is not possible to delete a disk that is attached to an instance.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListOperations(self, request, context):
        """Lists operations for the specified disk.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Move(self, request, context):
        """Moves the specified disk to another folder of the same cloud.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListSnapshotSchedules(self, request, context):
        """Retrieves the list of snapshot schedules the specified disk is attached to.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_DiskServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Get': grpc.unary_unary_rpc_method_handler(
                    servicer.Get,
                    request_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_disk__service__pb2.GetDiskRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_disk__pb2.Disk.SerializeToString,
            ),
            'List': grpc.unary_unary_rpc_method_handler(
                    servicer.List,
                    request_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_disk__service__pb2.ListDisksRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_disk__service__pb2.ListDisksResponse.SerializeToString,
            ),
            'Create': grpc.unary_unary_rpc_method_handler(
                    servicer.Create,
                    request_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_disk__service__pb2.CreateDiskRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Update': grpc.unary_unary_rpc_method_handler(
                    servicer.Update,
                    request_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_disk__service__pb2.UpdateDiskRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Delete': grpc.unary_unary_rpc_method_handler(
                    servicer.Delete,
                    request_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_disk__service__pb2.DeleteDiskRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'ListOperations': grpc.unary_unary_rpc_method_handler(
                    servicer.ListOperations,
                    request_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_disk__service__pb2.ListDiskOperationsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_disk__service__pb2.ListDiskOperationsResponse.SerializeToString,
            ),
            'Move': grpc.unary_unary_rpc_method_handler(
                    servicer.Move,
                    request_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_disk__service__pb2.MoveDiskRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'ListSnapshotSchedules': grpc.unary_unary_rpc_method_handler(
                    servicer.ListSnapshotSchedules,
                    request_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_disk__service__pb2.ListDiskSnapshotSchedulesRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_disk__service__pb2.ListDiskSnapshotSchedulesResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'yandex.cloud.compute.v1.DiskService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class DiskService(object):
    """A set of methods for managing Disk resources.
    """

    @staticmethod
    def Get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.compute.v1.DiskService/Get',
            yandex_dot_cloud_dot_compute_dot_v1_dot_disk__service__pb2.GetDiskRequest.SerializeToString,
            yandex_dot_cloud_dot_compute_dot_v1_dot_disk__pb2.Disk.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def List(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.compute.v1.DiskService/List',
            yandex_dot_cloud_dot_compute_dot_v1_dot_disk__service__pb2.ListDisksRequest.SerializeToString,
            yandex_dot_cloud_dot_compute_dot_v1_dot_disk__service__pb2.ListDisksResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.compute.v1.DiskService/Create',
            yandex_dot_cloud_dot_compute_dot_v1_dot_disk__service__pb2.CreateDiskRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.compute.v1.DiskService/Update',
            yandex_dot_cloud_dot_compute_dot_v1_dot_disk__service__pb2.UpdateDiskRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.compute.v1.DiskService/Delete',
            yandex_dot_cloud_dot_compute_dot_v1_dot_disk__service__pb2.DeleteDiskRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListOperations(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.compute.v1.DiskService/ListOperations',
            yandex_dot_cloud_dot_compute_dot_v1_dot_disk__service__pb2.ListDiskOperationsRequest.SerializeToString,
            yandex_dot_cloud_dot_compute_dot_v1_dot_disk__service__pb2.ListDiskOperationsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Move(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.compute.v1.DiskService/Move',
            yandex_dot_cloud_dot_compute_dot_v1_dot_disk__service__pb2.MoveDiskRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListSnapshotSchedules(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.compute.v1.DiskService/ListSnapshotSchedules',
            yandex_dot_cloud_dot_compute_dot_v1_dot_disk__service__pb2.ListDiskSnapshotSchedulesRequest.SerializeToString,
            yandex_dot_cloud_dot_compute_dot_v1_dot_disk__service__pb2.ListDiskSnapshotSchedulesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/cdn/v1/provider_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/cdn/v1/provider_service.proto',
  package='yandex.cloud.cdn.v1',
  syntax='proto3',
  serialized_options=b'\n\027yandex.cloud.api.cdn.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/cdn/v1;cdn',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n*yandex/cloud/cdn/v1/provider_service.proto\x12\x13yandex.cloud.cdn.v1\x1a\x1cgoogle/api/annotations.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"_\n\x17\x41\x63tivateProviderRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12#\n\rprovider_type\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\";\n\x18\x41\x63tivateProviderMetadata\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"@\n\x1dListActivatedProvidersRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"3\n\x1eListActivatedProvidersResponse\x12\x11\n\tproviders\x18\x01 \x03(\t2\xe1\x02\n\x0fProviderService\x12\xb7\x01\n\x08\x41\x63tivate\x12,.yandex.cloud.cdn.v1.ActivateProviderRequest\x1a!.yandex.cloud.operation.Operation\"Z\x82\xd3\xe4\x93\x02\x1f\"\x1a/cdn/v1/providers:activate:\x01*\xb2\xd2*1\n\x18\x41\x63tivateProviderMetadata\x12\x15google.protobuf.Empty\x12\x93\x01\n\rListActivated\x12\x32.yandex.cloud.cdn.v1.ListActivatedProvidersRequest\x1a\x33.yandex.cloud.cdn.v1.ListActivatedProvidersResponse\"\x19\x82\xd3\xe4\x93\x02\x13\x12\x11/cdn/v1/providersBV\n\x17yandex.cloud.api.cdn.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/cdn/v1;cdnb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,yandex_dot_cloud_dot_api_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_operation_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,])




_ACTIVATEPROVIDERREQUEST = _descriptor.Descriptor(
  name='ActivateProviderRequest',
  full_name='yandex.cloud.cdn.v1.ActivateProviderRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.cdn.v1.ActivateProviderRequest.folder_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='provider_type', full_name='yandex.cloud.cdn.v1.ActivateProviderRequest.provider_type', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=202,
  serialized_end=297,
)


_ACTIVATEPROVIDERMETADATA = _descriptor.Descriptor(
  name='ActivateProviderMetadata',
  full_name='yandex.cloud.cdn.v1.ActivateProviderMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.cdn.v1.ActivateProviderMetadata.folder_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=299,
  serialized_end=358,
)


_LISTACTIVATEDPROVIDERSREQUEST = _descriptor.Descriptor(
  name='ListActivatedProvidersRequest',
  full_name='yandex.cloud.cdn.v1.ListActivatedProvidersRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.cdn.v1.ListActivatedProvidersRequest.folder_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=360,
  serialized_end=424,
)


_LISTACTIVATEDPROVIDERSRESPONSE = _descriptor.Descriptor(
  name='ListActivatedProvidersResponse',
  full_name='yandex.cloud.cdn.v1.ListActivatedProvidersResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='providers', full_name='yandex.cloud.cdn.v1.ListActivatedProvidersResponse.providers', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=426,
  serialized_end=477,
)

DESCRIPTOR.message_types_by_name['ActivateProviderRequest'] = _ACTIVATEPROVIDERREQUEST
DESCRIPTOR.message_types_by_name['ActivateProviderMetadata'] = _ACTIVATEPROVIDERMETADATA
DESCRIPTOR.message_types_by_name['ListActivatedProvidersRequest'] = _LISTACTIVATEDPROVIDERSREQUEST
DESCRIPTOR.message_types_by_name['ListActivatedProvidersResponse'] = _LISTACTIVATEDPROVIDERSRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ActivateProviderRequest = _reflection.GeneratedProtocolMessageType('ActivateProviderRequest', (_message.Message,), {
  'DESCRIPTOR' : _ACTIVATEPROVIDERREQUEST,
  '__module__' : 'yandex.cloud.cdn.v1.provider_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.cdn.v1.ActivateProviderRequest)
  })
_sym_db.RegisterMessage(ActivateProviderRequest)

ActivateProviderMetadata = _reflection.GeneratedProtocolMessageType('ActivateProviderMetadata', (_message.Message,), {
  'DESCRIPTOR' : _ACTIVATEPROVIDERMETADATA,
  '__module__' : 'yandex.cloud.cdn.v1.provider_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.cdn.v1.ActivateProviderMetadata)
  })
_sym_db.RegisterMessage(ActivateProviderMetadata)

ListActivatedProvidersRequest = _reflection.GeneratedProtocolMessageType('ListActivatedProvidersRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTACTIVATEDPROVIDERSREQUEST,
  '__module__' : 'yandex.cloud.cdn.v1.provider_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.cdn.v1.ListActivatedProvidersRequest)
  })
_sym_db.RegisterMessage(ListActivatedProvidersRequest)

ListActivatedProvidersResponse = _reflection.GeneratedProtocolMessageType('ListActivatedProvidersResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTACTIVATEDPROVIDERSRESPONSE,
  '__module__' : 'yandex.cloud.cdn.v1.provider_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.cdn.v1.ListActivatedProvidersResponse)
  })
_sym_db.RegisterMessage(ListActivatedProvidersResponse)


DESCRIPTOR._options = None
_ACTIVATEPROVIDERREQUEST.fields_by_name['folder_id']._options = None
_ACTIVATEPROVIDERREQUEST.fields_by_name['provider_type']._options = None
_ACTIVATEPROVIDERMETADATA.fields_by_name['folder_id']._options = None
_LISTACTIVATEDPROVIDERSREQUEST.fields_by_name['folder_id']._options = None

_PROVIDERSERVICE = _descriptor.ServiceDescriptor(
  name='ProviderService',
  full_name='yandex.cloud.cdn.v1.ProviderService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=480,
  serialized_end=833,
  methods=[
  _descriptor.MethodDescriptor(
    name='Activate',
    full_name='yandex.cloud.cdn.v1.ProviderService.Activate',
    index=0,
    containing_service=None,
    input_type=_ACTIVATEPROVIDERREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002\037\"\032/cdn/v1/providers:activate:\001*\262\322*1\n\030ActivateProviderMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListActivated',
    full_name='yandex.cloud.cdn.v1.ProviderService.ListActivated',
    index=1,
    containing_service=None,
    input_type=_LISTACTIVATEDPROVIDERSREQUEST,
    output_type=_LISTACTIVATEDPROVIDERSRESPONSE,
    serialized_options=b'\202\323\344\223\002\023\022\021/cdn/v1/providers',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_PROVIDERSERVICE)

DESCRIPTOR.services_by_name['ProviderService'] = _PROVIDERSERVICE

# @@protoc_insertion_point(module_scope)
